@@ -31,6 +31,8 @@ class var_store(object):
 		to using the square-bracket (`[my_variable]`) notation, and logged by
 		the LOGGER item.
 
+		A `var` object is created automatically when the experiment starts.
+
 		In addition to the functions listed below, the following semantics are
 		supported:
 
@@ -185,6 +187,9 @@ class var_store(object):
 			preserve:
 				desc:	A list of variable names that shouldn't be cleared.
 				type:	list
+
+		example: |
+			var.clear()
 		"""
 
 		for var in list(self.__vars__.keys()):
@@ -227,39 +232,62 @@ class var_store(object):
 		self._check_var_name(var)
 		if self.__lock__ == var:
 			raise osexception(
-				u"Recursion detected! Is variable '%s' defined in terms of itself (e.g., 'var = [var]') in item '%s'" \
-				% (var, self.name))
+				(
+					u"Recursion detected! Is variable '%s' defined in terms of "
+					u"itself (e.g., 'var = [var]') in item '%s'"
+				) % (var, self.name)
+			)
 		if var in self.__vars__:
 			val = self.__vars__[var]
 		elif hasattr(self.__item__, var):
-			warnings.warn(u'var %s is stored as attribute of item %s' \
-				% (var, self.__item__.name))
+			warnings.warn(
+				u'var %s is stored as attribute of item %s'
+				% (var, self.__item__.name)
+			)
 			val = getattr(self.__item__, var)
 		elif self.__parent__ is not None:
-			val = self.__parent__.get(var, default=default, _eval=_eval,
-				valid=valid)
+			val = self.__parent__.get(
+				var,
+				default=default,
+				_eval=_eval,
+				valid=valid
+			)
 		elif default is not None:
 			val = default
 		else:
-			raise osexception((u'The variable \'%s\' does not exist. Tip: Use '
-				u'the variable inspector (Ctrl+I) to see all variables.') % var)
+			raise osexception(
+				(
+					u'The variable \'%s\' does not exist. Tip: Use '
+					u'the variable inspector (Ctrl+I) to see all variables.'
+				) % var
+			)
 		if valid is not None and val not in valid:
-			raise osexception(u'Variable %s should be in %s, not %s' \
-				% (var, valid, val))
+			raise osexception(
+				u'Variable %s should be in %s, not %s'
+				% (var, valid, val)
+			)
 		if _eval:
 			object.__setattr__(self, u'__lock__', var)
 			val = self.__item__.syntax.eval_text(val)
 			object.__setattr__(self, u'__lock__', None)
 		if isinstance(val, bool):
-			if val:
-				return u'yes'
-			return u'no'
+			return u'yes' if val else u'no'
+		# The logic here is that we first try to convert to float, and if this
+		# is not successful, return the orignal type. If this is succesful we
+		# turn the float into an int if this doesn't result in data loss, and
+		# otherwise return the float.
 		try:
 			val = float(val)
-		except:
+		except (TypeError, ValueError):
 			return val
-		if int(val) == val:
-			return int(val)
+		try:
+			if int(val) == val:
+				return int(val)
+		except (ValueError, ArithmeticError):
+			# A float can always be converted to an int, except nan values,
+			# which result in ValueError, or inf values, which result in an
+			# OverFlowError (which is a subclass of ArithmeticError).
+			pass
 		return val
 
 	def has(self, var):
@@ -366,6 +394,10 @@ class var_store(object):
 		returns:
 			desc:	A list of variable names.
 			type:	list
+
+		example: |
+			for varname in var.vars():
+				print(varname)
 		"""
 
 		return sorted(list(self.__vars__.keys()))
@@ -374,12 +406,16 @@ class var_store(object):
 
 		"""
 		desc:
-			Returns a list of (variable_name, value) tuples. See [vars] for a
-			note about the non-exhaustiveness of this function.
+			Returns a list of (variable_name, value) tuples. See `var.vars()`
+			for a note about the non-exhaustiveness of this function.
 
 		returns:
 			desc:	A list of (variable_name, value) tuples.
 			type:	list
+
+		example: |
+			for varname, value in var.items():
+				print(varname, value)
 		"""
 
 		return list(self.__vars__.items())
@@ -425,6 +461,14 @@ class var_store(object):
 		desc:
 			Implements custom pickling. See var_store_pickle.
 		"""
+		
+		try:
+			# If the parent var store is specified and is not None, then this
+			# is a var store of an item, and we don't pickle it.
+			if self.__parent__ is not None:
+				return None
+		except AttributeError:
+			pass
 		return (var_store_pickle, (self.inspect(), ))
 
 class var_store_pickle(var_store):
