@@ -25,21 +25,8 @@ import os
 from libopensesame.oslogging import oslogger
 try:
 	import markdown
-	from distutils.version import LooseVersion
-	# TocExtension() doesn't support the title keyword in previous versions
-	# This seems to have been added in 2.6 as part of the depraction of the
-	# HeaderID extension:
-	# https://github.com/waylan/Python-Markdown/releases/tag/2.6-final
-	if LooseVersion(markdown.version) > LooseVersion(u'2.6'):
-		from markdown.extensions import attr_list, extra, toc
-	else:
-		oslogger.warning(
-			u'Markdown disabled for markdown version: {}'.format(
-				markdown.version
-			)
-		)
-		markdown = None
-except:
+	from markdown.extensions import attr_list, extra, toc
+except ImportError:
 	oslogger.error(u'Unable to import markdown, proceeding without markdown')
 	markdown = None
 try:
@@ -86,7 +73,7 @@ class markdown_parser(base_subcomponent):
 			self.css += self.html_formatter.get_style_defs(u'.highlight')
 			self.re_script = re.compile(
 				r'^~~~\s*.(?P<syntax>\w+)(?P<script>.*?)^~~~', re.S | re.M)
-		self.css += u'</style>'
+		self.css += u'</style><link href="https://fonts.googleapis.com/css?family=Roboto+Slab&display=swap" rel="stylesheet">'
 		if markdown is not None:
 			self.ext = [attr_list.AttrListExtension(), extra.ExtraExtension(),
 				toc.TocExtension(title=u'Overview'),
@@ -97,10 +84,10 @@ class markdown_parser(base_subcomponent):
 </p>
 
 <div class="footer">
-OpenSesame %s %s —
-Copyright <a href="http://www.cogsci.nl/smathot">Sebastiaan Mathôt</a> 2010-2018
+%s
+Copyright <a href="http://www.cogsci.nl/smathot">Sebastiaan Mathôt</a> 2010-2022
 </div>
-''' % (_(u'Dismiss this message'), metadata.__version__, metadata.codename)
+''' % (_(u'Dismiss this message'), metadata.identity)
 
 	def highlight(self, md):
 
